@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2009, 2010 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009, 2010 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "importhelper.h"
 #include "window/mainwindow.h"
@@ -37,7 +25,12 @@ int main(int argc, char** argv)
 
     KLocalizedString::setApplicationDomain("palapeli");
 
-    KAboutData about(QStringLiteral("palapeli"), i18nc("The application's name", "Palapeli"), PALAPELI_VERSION_STRING, i18n("KDE Jigsaw Puzzle Game"), KAboutLicense::GPL, i18n("Copyright 2009, 2010, Stefan Majewsky"));
+    KAboutData about(QStringLiteral("palapeli"),
+                     i18nc("The application's name", "Palapeli"),
+                     QStringLiteral(PALAPELI_VERSION_STRING),
+                     i18n("Jigsaw Puzzle Game"),
+                     KAboutLicense::GPL,
+                     i18n("Copyright 2009, 2010, Stefan Majewsky"));
     about.addAuthor(i18n("Stefan Majewsky"), QString(), QStringLiteral("majewsky@gmx.net"), QStringLiteral("https://majewsky.wordpress.com/"));
     about.addCredit (i18n ("Johannes Loehnert"),
             i18n ("The option to preview the completed puzzle"),
